term_setsFunction to assign colours to terms based on frequency with which terms appear in term_sets
colour_by_frequency(
ontology,
terms,
term_sets,
colour_func = colorRampPalette(c("Yellow", "Green", "#0099FF"))
)Character vector of colours, named by term
ontology_index object
Character vector of ontological terms
List of character vectors of ontological term IDs
Function capable of returning a set of colours, given the number of colours it needs to return
colour_by_term_set, colour_by_population_frequency