Function to assign colours to terms based on population frequency of terms
colour_by_population_frequency(
ontology,
terms,
frequencies,
colour_palette = colorRampPalette(c("Yellow", "Green", "#0099FF"))(10),
max_colour_freq = max(terms_freq),
min_colour_freq = min(terms_freq)
)Character vector of colours, named by term
ontology_index object
Character vector of ontological terms
Numeric vector of term frequencies named by term IDs
Character vector of colours for the different information contents of the terms to be plotted, going from rare to common
Numeric value in [0, 1] giving the maximum frequency (to which the dullest color will be assigned)
Numeric value in [0, 1] giving the minimum frequency (to which the brightest color will be assigned)
colour_by_term_set, colour_by_frequency