Learn R Programming

ontologyPlot (version 1.0)

colour_by_term_set: Function to set colours of nodes in plot to distinguish terms belonging to different term sets

Description

Function to set colours of nodes in plot to distinguish terms belonging to different term sets

Usage

colour_by_term_set(ontology, terms, term_sets)

Arguments

ontology
ontology_index object
terms
Character vector of ontological terms
term_sets
List of character vectors of ontological term IDs

Value

Character vector of colours, named by term.

See Also

colour_by_frequency, colour_by_population_frequency