Learn R Programming

ontologyPlot (version 1.0)

p_values_for_occurrence_of_term_in_group: Get p-values for observing at least as many of each term as occur in term_sets given the population frequencies of the terms

Description

Get p-values for observing at least as many of each term as occur in term_sets given the population frequencies of the terms

Usage

p_values_for_occurrence_of_term_in_group(ontology, term_sets, terms_freq)

Arguments

ontology
ontology_index object
term_sets
List of character vectors of ontological term IDs
terms_freq
Numeric vector of population frequencies of terms.

Value

Numeric vector of log p-values named by correspnding term.

See Also

width_by_significance