Learn R Programming

ontologyPlot (version 1.0)

remove_terms_with_less_than_n_occurrences: Remove terms with less than certain number of occurrences

Description

Remove terms with less than certain number of occurrences

Usage

remove_terms_with_less_than_n_occurrences(ontology, term_sets, n, terms = unique(unlist(term_sets)))

Arguments

ontology
ontology_index object
term_sets
List of character vectors of ontological term IDs
n
Integer
terms
Character vector of ontological terms

Value

Character vector

See Also

n_most_frequent_terms

Examples

Run this code
library(ontologyIndex)
data(hpo)
remove_terms_with_less_than_n_occurrences(hpo, 
term_sets=list("HP:0001873", "HP:0001902"), n=2)

Run the code above in your browser using DataLab