Learn R Programming

ontologyPlot (version 1.0)

colour_by_frequency: Function to assign colours to terms based on frequency with which terms appear in term_sets

Description

Function to assign colours to terms based on frequency with which terms appear in term_sets

Usage

colour_by_frequency(ontology, terms, term_sets, colour_func = colorRampPalette(c("Yellow", "Green", "#0099FF")))

Arguments

ontology
ontology_index object
terms
Character vector of ontological terms
term_sets
List of character vectors of ontological term IDs
colour_func
Function capable of returning a set of colours, given the number of colours it needs to return

Value

Character vector of colours, named by term

See Also

colour_by_term_set, colour_by_population_frequency