Learn R Programming

ontologyPlot (version 1.0)

colour_by_population_frequency: Function to assign colours to terms based on population frequency of terms

Description

Function to assign colours to terms based on population frequency of terms

Usage

colour_by_population_frequency(ontology, terms, frequencies, colour_palette = colorRampPalette(c("Yellow", "Green", "#0099FF"))(10), max_colour_freq = max(terms_freq), min_colour_freq = min(terms_freq))

Arguments

ontology
ontology_index object
terms
Character vector of ontological terms
frequencies
Numeric vector of term frequencies named by term IDs
colour_palette
Character vector of colours for the different information contents of the terms to be plotted, going from rare to common
max_colour_freq
Numeric value in [0, 1] giving the maximum frequency (to which the dullest color will be assigned)
min_colour_freq
Numeric value in [0, 1] giving the minimum frequency (to which the brightest color will be assigned)

Value

Character vector of colours, named by term

See Also

colour_by_term_set, colour_by_frequency