Learn R Programming

ontologyPlot (version 1.0)

label_by_frequency: Function to get plot labels for terms based on frequency in term_sets

Description

Function to get plot labels for terms based on frequency in term_sets

Usage

label_by_frequency(ontology, terms, term_sets)

Arguments

ontology
ontology_index object
terms
Character vector of ontological terms
term_sets
List of character vectors of ontological term IDs

Value

Character vector of labels, named by term.

See Also

simple_labels, long_labels