term_setsFunction to get node sizes for terms based on statistical significance of seeing at least this number of each term in term_sets
width_by_significance(ontology, terms, term_sets, frequencies)Character vector of sizes, named by term
ontology_index object
Character vector of ontological terms
List of character vectors of ontological term IDs
Numeric vector of term frequencies named by term IDs
width_by_frequency