Learn R Programming

ontologyPlot (version 1.0)

width_by_significance: Function to get node sizes for terms based on statistical significance of seeing at least this number of each term in term_sets

Description

Function to get node sizes for terms based on statistical significance of seeing at least this number of each term in term_sets

Usage

width_by_significance(ontology, terms, term_sets, frequencies)

Arguments

ontology
ontology_index object
terms
Character vector of ontological terms
term_sets
List of character vectors of ontological term IDs
frequencies
Numeric vector of term frequencies named by term IDs

Value

Character vector of sizes, named by term

See Also

width_by_frequency